<p align="center">
  <a href="https://github.com/mondeja/mdpo"><img src="https://raw.githubusercontent.com/mondeja/mdpo/master/mdpo.png" alt="mdpo" width="400"></a>
</h1>

<h4 align="center">Markdown files translation using PO files</h4>

<p align="center">
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/v/mdpo"
         alt="PyPI">
  </a>
  <a href="https://pypi.org/project/mdpo/">
    <img src="https://img.shields.io/pypi/pyversions/mdpo?labelColor=333333">
  </a>
  <a href="https://github.com/mondeja/mdpo/blob/master/LICENSE">
    <img src="https://img.shields.io/pypi/l/mdpo?color=light-green">
  </a>
</p>

<h2 align="center">
  <a href="https://mdpo.readthedocs.io/en/master/">Documentation</a>
</h2>

<p align="center">
Complies with <a href="https://spec.commonmark.org/">CommonMark Specification</a>
<a href="https://spec.commonmark.org/0.29">v0.29</a> and
<a href="https://spec.commonmark.org/0.30">v0.30</a>, supporting some
additional features.
</p>

## Status

[![Documentation status][doc-image]][doc-link]
[![Tests][tests-image]][tests-link]
[![Coverage status][coverage-image]][coverage-link]

## Installation

```bash
pip install mdpo
```

[tests-image]: https://img.shields.io/github/workflow/status/mondeja/mdpo/Test?logo=github&label=tests
[tests-link]: https://github.com/mondeja/mdpo/actions?query=workflow%3ATest
[coverage-image]: https://img.shields.io/coveralls/github/mondeja/mdpo?logo=coveralls
[coverage-link]: https://coveralls.io/github/mondeja/mdpo
[doc-image]: https://img.shields.io/readthedocs/mdpo/master?logo=read-the-docs&logoColor=white
[doc-link]: https://mdpo.readthedocs.io/en/master/
